import { StandardFargateService, StandardFargateServiceProps } from './standard-fargate-service';
import { Construct } from 'constructs';
import { Duration } from 'aws-cdk-lib';
import { ApplicationProtocol, IApplicationListener, IApplicationLoadBalancer, TargetGroupLoadBalancingAlgorithmType } from 'aws-cdk-lib/aws-elasticloadbalancingv2';
import { ARecord, IHostedZone } from 'aws-cdk-lib/aws-route53';
import { DomainName } from '../../aws-route53';
/**
 * Properties for StandardApplicationFargateService
 */
export interface StandardApplicationFargateServiceProps extends StandardFargateServiceProps {
    /**
     * The name of an application-based stickiness cookie.
     *
     * @default - lb_affinity
     */
    readonly stickinessCookieName?: string;
    /**
     * The stickiness cookie expiration period. Set to 0 to disable.
     *
     * @default - Duration.days(1)
     */
    readonly stickinessCookieDuration?: Duration;
    /**
     * The time period during which the load balancer sends a newly registered target a
     * linearly increasing share of the traffic to the target group. Set this to 0
     * to disable.
     *
     * @default - Duration.seconds(30)
     */
    readonly slowStart?: Duration;
    /**
     * The protocol used by the application in the container.
     *
     * @default - ApplicationProtocol.HTTP
     */
    readonly applicationProtocol?: ApplicationProtocol;
    /**
     * The amount of time for Elastic Load Balancing to wait before deregistering a target.
     *
     * @default - Duration.seconds(10)
     */
    readonly deregistrationDelay?: Duration;
    /**
     * The approximate number of seconds between health checks for an individual target.
     *
     * @default - Duration.seconds(10)
     */
    readonly healthCheckInterval?: Duration;
    /**
     * The ping path destination where Elastic Load Balancing sends health check requests.
     *
     * @default - /health
     */
    readonly healthCheckPath?: string;
    /**
     * The amount of time, in seconds, during which no response from a target means a failed health check
     *
     * @default - Duration.seconds(3)
     */
    readonly healthCheckTimeout?: Duration;
    /**
     * The number of consecutive health checks successes required before considering an unhealthy target healthy.
     *
     * @default - 2
     */
    readonly healthyThresholdCount?: number;
    /**
     * The number of consecutive health check failures required before considering a target unhealthy.
     *
     * @default - 2
     */
    readonly unhealthyThresholdCount?: number;
    /**
     * HTTP code to use when checking for a successful response from a target
     *
     * @default - 200-299
     */
    readonly healthyHttpCodes?: string;
    /**
     * The load balancing algorithm to select targets for routing requests.
     * To set this to LEAST_OUTSTANDING_REQUESTS, stickiness must be disabled.
     *
     * @default - ROUND_ROBIN
     */
    readonly loadBalancingAlgorithmType?: TargetGroupLoadBalancingAlgorithmType;
    /**
     * The number of ALB requests to target for scaling.
     * Disabled by default.
     */
    readonly scaleRequestPerTarget?: number;
    /**
     * Domain name associated with this service.
     */
    readonly domainName?: string;
    /**
     * Additional domain names to associate with this service.
     */
    readonly domainNames?: string[];
    /**
     * Set this to true to skip the creation of route53 records. By default records will be created in domainName and domainZone is provided.
     *
     * @default - false
     */
    readonly skipCreateRoute53Records?: boolean;
    /**
     * Path pattern to match on the load balancer.
     *
     * @default - ["/*"]
     */
    readonly pathPattern?: string[];
    /**
     * Load balancer to attach this service to. If passed an ARN or name a lookup will be
     * performed to locate the load balancer.
     */
    readonly loadBalancer: IApplicationLoadBalancer | string;
    /**
     * The listener to attach this service to. If one is not provided an HTTPS listener is obtained from a lookup.
     *
     * @default - ApplicationProtocol.HTTPS
     */
    readonly listener?: IApplicationListener;
    /**
     * The priority to give the target group on the ALB.
     *
     * @default - 1
     */
    readonly targetGroupPriority?: number;
    /**
     * Zone of the domain name. If set, a route53 record is created for the service.
     *
     */
    readonly domainZone?: IHostedZone;
}
/**
 * Creates an ECS Fargate service and maps it to an Application Load Balancer (ALB).
 */
export declare class StandardApplicationFargateService extends StandardFargateService {
    readonly loadBalancer: IApplicationLoadBalancer;
    readonly listener: IApplicationListener;
    readonly domainName?: DomainName;
    readonly route53Record?: ARecord;
    constructor(scope: Construct, id: string, props: StandardApplicationFargateServiceProps);
}
